@@ -325,6 +325,17 @@ sub ConvertTimezoneFunction {
     return $res;
 }
 
+sub _DateTimeIntervalFunction {
+    my $self = shift;
+    my %args = ( From => undef, To => undef, @_ );
+
+    return "(EXTRACT(EPOCH FROM $args{'To'}) - EXTRACT(EPOCH FROM $args{'From'}))";
+}
+
+sub HasSupportForNullsOrder {
+    return 1;
+}
+
 1;
 
 __END__
